import * as definition from '.';
/**
 * Defines a position within string, in line and column form.
 */
export interface Position {
    /**
     * The line number. The first line is at index 1.
     */
    line: number;
    /**
     * The column number. The first character is at index 1.
     */
    column: number;
}
export declare class ParserEventType implements definition.ParserEventType {
    static StartElement: string;
    static EndElement: string;
    static Text: string;
    static CDATA: string;
    static Comment: string;
}
export declare class ParserEvent implements definition.ParserEvent {
    private _eventType;
    private _position;
    private _prefix;
    private _namespace;
    private _elementName;
    private _attributes;
    private _data;
    constructor(eventType: string, position: Position, prefix?: string, namespace?: string, elementName?: string, attributes?: Object, data?: string);
    toString(): string;
    get eventType(): string;
    get position(): Position;
    get prefix(): string;
    get namespace(): string;
    get elementName(): string;
    get attributes(): Object;
    get data(): string;
}
export declare class XmlParser implements definition.XmlParser {
    private _parser;
    private _processNamespaces;
    private _namespaceStack;
    constructor(onEvent: (event: definition.ParserEvent) => void, onError?: (error: Error, position: Position) => void, processNamespaces?: boolean);
    get angularSyntax(): boolean;
    set angularSyntax(value: boolean);
    parse(xmlString: string): void;
    private static _getNamespacesStackEntry;
    private _resolveNamespace;
    private static _dereferenceEntities;
}
